@@ -606,7 +606,7 @@ class MainWindow(hildon.StackableWindow):
 
     def read_config(self):
         config = ConfigParser.SafeConfigParser()
-        config.read('fSchedule.default')
+        config.read('./fSchedule.default')
         self.defaultsite = int(config.get('default', 'defaultsite'))
 
     def write_config(self):
@@ -614,7 +614,7 @@ class MainWindow(hildon.StackableWindow):
         config.read('fSchedule.default')
         config.set('default', 'defaultsite', str(self.defaultsite))
         # Writing our configuration file to 'example.cfg'
-        config.write(open('fSchedule.default', 'w'))
+        config.write(open('./fSchedule.default', 'w'))
 
         
 class fSchedule(hildon.Program):
